OC.L10N.register(
    "settings",
    {
    "Private" : "خاص بك",
    "Local" : "المحلي",
    "Only visible to people on this instance and guests" : "ظاهر فقط للمستخدمين والضيوف",
    "Federated" : "المتحدة",
    "Only synchronize to trusted servers" : "قم فقط بالمزامنة مع الخوادم الموثوقة",
    "Published" : "نشرت",
    "Synchronize to trusted servers and the global and public address book" : "قم بالمزامنة مع الخوادم الموثوقة ودفتر العناوين العالمية والعامة",
    "Verify" : "تحقق",
    "Verifying …" : "عملية التحقق جارية …",
    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "So-so password" : "كلمة سر غير فعالة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Groups" : "مجموعات",
    "Group list is empty" : "قائمة المجموعة فارغة",
    "{actor} changed your password" : "{actor} قام بتغيير كلمتك السرية",
    "You changed your password" : "لقد قمت بتعديل كلمة مرورك",
    "Your password was reset by an administrator" : "قام أحد المدراء بإعادة تعيين كلمة مرورك",
    "{actor} changed your email address" : "{actor} قام بتغيير عنوان بريدك الإلكتروني",
    "You changed your email address" : "لقد قمت بتعديل عنوان بريدك الإلكتروني",
    "Your email address was changed by an administrator" : "قام أحد المدراء بتغيير عنوان بريدك الإلكتروني",
    "Security" : "الأمان",
    "Wrong password" : "كلمة مرور خاطئة",
    "Saved" : "حفظ",
    "No user supplied" : "لم يتم توفير مستخدم ",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
    "Federated Cloud Sharing" : "المشاركة السحابية الموحّدة",
    "Invalid SMTP password." : "كلمة مرور SMTP خاطئة.",
    "Email setting test" : "تجريب إعدادات البريد الإلكتروني",
    "Well done, %s!" : "حسنًا فعلت، %s !",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "حدث خطأ أثناء إرسال البريد الإلكتروني. برجى مراجعة الاعدادات. (خطأ: %s)",
    "Invalid user" : "مستخدم غير صالح",
    "Invalid mail address" : "عنوان البريد الإلكتروني خاطئ",
    "Settings saved" : "تم حفظ الإعدادات",
    "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
    "Password changed for %s" : "تم تعديل كلمة سر %s",
    "Your %s account was created" : "تم إنشاء حسابك %s",
    "Welcome aboard" : "مرحبًا بكم على متن ناكست كلاود",
    "Welcome aboard %s" : "مرحبًا بكم على متن ناكست كلاود يا %s",
    "Your username is: %s" : "إسم المستخدم الخاص بك هو : %s",
    "Set your password" : "قم بإدخال كلمتك السرية",
    "Go to %s" : "الإنتقال إلى %s",
    "Install Client" : "تنصيب العميل",
    "Apps" : "التطبيقات",
    "Settings" : "الإعدادات",
    "Personal" : "شخصي",
    "Administration" : "الإدارة",
    "Additional settings" : "الإعدادات المتقدمة",
    "Overview" : "نظرة شاملة",
    "Basic settings" : "الإعدادات الأساسية",
    "Sharing" : "مشاركة",
    "Personal info" : "المعلومات الشخصية",
    "Mobile & desktop" : "الجوال وسطح المكتب",
    "Email server" : "خادوم البريد",
    "Security & setup warnings" : "تحذيرات الإعداد و الأمان",
    "Background jobs" : "الأنشطة في الخلفية",
    "Create" : "إنشاء",
    "Change" : "تعديل",
    "Delete" : "إلغاء",
    "Reshare" : "إعادة المشاركة",
    "Unlimited" : "غير محدود",
    "Verifying" : "التحقق",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "العمليات الخلفية قيد الانتظار يتم فحص شهادة الآمان SSL تمت اضافتها من المستخدم. يرجى المحاولة لاحقاً.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "يوجد مستخدم رفع شهادة آمان SSL حاليا، لا تستخدم حاليا مع Nextcloud 21. يمكن رفعها باستخدام سطر الامر عبر \"occ security:certificates:import\". داخل مجلد data كما هو موضح.",
    "None" : "لا شيء",
    "Two-Factor Authentication" : "المصادقة بخطوتين",
    "Limit to groups" : "التقيد إلى مجموعات",
    "Save changes" : "حفظ التعديلات",
    "All" : "الكل",
    "No results" : "دون أية نتيجة",
    "Update to {version}" : "التحديث إلى {version}",
    "Remove" : "حذف",
    "Disable" : "إيقاف",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "هذا التطبيق لم يتم اضافة آخر إصدار متوافق مع اصدارات Nextcloud. هذا قد يسبب خطأ في المستقبل.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "هذا التطبيق لم يتم اضافة آخر إصدار متوافق مع اصدارات Nextcloud. هذا قد يسبب خطأ في المستقبل.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "لا يمكن تحميل التطبيق بسبب عدم العثور على الاضافات المطلوبة:",
    "View in store" : "العرض على المتجر",
    "Visit website" : "زر الموقع",
    "Report a bug" : "الإبلاغ عن عِلّة",
    "User documentation" : "دليل المستخدم",
    "Admin documentation" : "دليل المدير",
    "Developer documentation" : "دليل المُطوّر",
    "Featured" : "مميزة",
    "Results from other categories" : "نتائج عبر الفئات الأخرى",
    "No apps found for your version" : "لا يمكن العثور على تطبيقات للإصدار الخاص بك.",
    "Disable all" : "تعطيل الكل",
    "Enable all" : "تنشيط الكل",
    "Device settings" : "إعدادات الجهاز",
    "Allow filesystem access" : "السماح بالنفاذ إلى نظام الملفات",
    "Rename" : "تعديل الإسم",
    "Revoke" : "إلغاء",
    "Wipe device" : "تهيئة الجهاز",
    "Internet Explorer" : "إنترنت إكسبلورر",
    "Edge" : "آدج",
    "Firefox" : "فايرفوكس",
    "Google Chrome" : "غوغل كروم",
    "Safari" : "سفاري",
    "Google Chrome for Android" : "غوغل كروم لنظام الأندرويد",
    "iPhone" : "الآيفون",
    "This session" : "هذه الجلسة",
    "Device" : "الجهاز",
    "Last activity" : "آخر نشاط",
    "Error while creating device token" : "خطأ اثناء إنشاء Token للجهاز.",
    "Error while deleting the token" : "خطأ في حذف Token",
    "App name" : "إسم التطبيق",
    "Create new app password" : "إنشاء كلمة سرية جديدة للتطبيق",
    "Use the credentials below to configure your app or device." : "استخدم معلومات الدخول التالية لضبط تطبيقك أو جهازك.",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة المرور",
    "Done" : "تم",
    "Copied!" : "تم نسخه !",
    "Copy" : "نسخ",
    "Profile" : "الملف الشخصي",
    "Enable" : "تفعيل",
    "Server-side encryption" : "التشفير مِن جانب الخادوم",
    "Enable server-side encryption" : "تشغيل التشفير مِن جانب الخادوم",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "في حال تفعيل التشفير، عملية رفع الملف المشفر سيتم تفعيلها في الخادم. يمكن تعطيل التشفير في وقت لاحق فقط اذا كانت حزمة التشفير المفعلة تدعم التعطيل، وجميع الشروط الاخرى (على سبيل المثال اعداد رمز الاستعادة) مشمول ضمن الحزمة.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "التشفير لوحدها لا تضمن حماية النظام بشكل كامل. يرجى اتباع التعليمات لمزيد من المعلومات والحصول على معلومات عن عمل تطبيق التشفير، واستخداماته العديد.",
    "Be aware that encryption always increases the file size." : "تنويه حجم الملفات يزيد دائما مع استخدام التشفير.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "من الجيد سحب نسخ احتياطية بشكل معتاد لبياناتك، في حال كنت مفعل خاصية التشفير تأكد دائما من حصولك على رمز التشفير بالإضافة الى البيانات.",
    "This is the final warning: Do you really want to enable encryption?" : "هذا التحذير الاخير: هل تريد حقا تفعيل خاصية التشفير؟",
    "No encryption module loaded, please enable an encryption module in the app menu." : "لم يتم تحميل حزمة التشفير، يرجى تفعيل حزمة التشفير من قائمة التطبيق.",
    "Select default encryption module:" : "اختر حزمة التشفير الافتراضية:",
    "Remove group" : "حذف الفريق",
    "Current password" : "كلمات السر الحالية",
    "New password" : "كلمات سر جديدة",
    "Change password" : "عدل كلمة السر",
    "png or jpg, max. 20 MB" : "صيغة png أو jpg و حجم أقصاه 20 م.ب",
    "Picture provided by original account" : "الصورة المستخدمة من الحساب الاصلي",
    "Cancel" : "الغاء",
    "Details" : "التفاصيل",
    "You are a member of the following groups:" : "إنك عضو في الفِرَق التالية:",
    "Your email address" : "عنوانك البريدي",
    "No email address set" : "لم يتم إدخال أي عنوان للبريد الإلكتروني",
    "Language" : "اللغة",
    "Help translate" : "ساعد في الترجمة",
    "Your phone number" : "رقم هاتفك",
    "Add" : "إضافة",
    "Delete user" : "احذف المستخدم",
    "Welcome mail sent!" : "تم إرسال بريد الترحيب!",
    "Edit User" : "تعديل المستخدم",
    "New user" : "مستخدم جديد",
    "Display name" : "الاسم المعروض",
    "Email" : "البريد الإلكترونى",
    "Default language" : "اللغة الافتراضية",
    "Add a new user" : "إضافة مستخدِم جديد",
    "Group admin for" : "فريق المُدراء لـ",
    "Quota" : "حصه",
    "Storage location" : "مسار التخزين",
    "Last login" : "آخِر تسجيل للدخول",
    "Name your device" : "اسم جهازك",
    "Your browser does not support WebAuthn." : "متصفحك لا يدعم WebAuthn.",
    "Your apps" : "تطبيقاتك",
    "Active apps" : "التطبيقات النشطة",
    "Disabled apps" : "التطبيقات المعطلة",
    "Updates" : "التحديثات",
    "App bundles" : "حُزَم التطبيقات",
    "Changelog" : "سجل التغييرات",
    "Add group" : "إضافة فريق",
    "Active users" : "المستخدمون النشطون",
    "Admins" : "المدراء",
    "Disabled users" : "المستخدمون المُعطَّلون",
    "Default quota:" : "الحصة الافتراضية:",
    "Show Languages" : "اعرض اللغات",
    "Show user backend" : "عرض مستخدم لوحة التحكم الرئيسية",
    "Not saved" : "لم يتم حفظه",
    "Sending…" : "جارٍ الإرسال …",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Location" : "الموقع",
    "Profile picture" : "صورة الملف الشخصي",
    "About" : "عن",
    "Full name" : "الإسم الكامل",
    "Phone number" : "رقم الهاتف",
    "Role" : "الدور",
    "Twitter" : "تويتر",
    "Website" : "موقع الويب",
    "Hide" : "إخفاء",
    "Never" : "أبدا",
    "Administrator documentation" : "دليل المدير",
    "Documentation" : "الدليل",
    "Forum" : "منتدى",
    "Login" : "تسجيل الدخول",
    "Plain" : "سادة",
    "NT LAN Manager" : "مدير الشبكة المحلية LAN NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "فتح الدليل",
    "Send mode" : "وضعية الإرسال",
    "Encryption" : "التشفير",
    "From address" : "عنوان الإرسال",
    "Authentication method" : "أسلوب التطابق",
    "Authentication required" : "المصادقة مطلوبة",
    "Server address" : "عنوان الخادم",
    "Port" : "المنفذ",
    "Credentials" : "معلومات الدخول",
    "SMTP Username" : "إسم مستخدم الـ SMTP",
    "SMTP Password" : "كلمة مرور الـ SMTP",
    "Save" : "حفظ",
    "Send email" : "إرسال بريد إلكتروني",
    "All checks passed." : "تم اجتياز جميع الاختبارات.",
    "Version" : "إصدار",
    "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
    "Enforce expiration date" : "فرض تاريخ نهاية صلاحية",
    "Allow public uploads" : "السماح بالرفع للعامة ",
    "Always ask for a password" : "أطلب دائما كلمة السر",
    "Enforce password protection" : "فرض الحماية بكلمة مرور",
    "Set default expiration date" : "تعيين تاريخ إنتهاء الصلاحية الإفتراضية",
    "Allow resharing" : "السماح بإعادة المشاركة ",
    "Allow sharing with groups" : "السماح بالمشاركة مع المجموعات",
    "Restrict users to only share with users in their groups" : "سماح المستخدمين للمشاركة ضمن مجموعتهم فقط.",
    "Exclude groups from sharing" : "استبعاد المجموعات من المشاركة",
    "These groups will still be able to receive shares, but not to initiate them." : "هذه المجموعات لا زالت تستقبل المشاركات، لكن غير مطلعين عليها.",
    "Like our Facebook page" : "قم بالإعجاب بصفحتنا على الفايسبوك",
    "Follow us on Twitter" : "تابعونا على تويتر",
    "Follow us on Mastodon" : "تابعونا على ماستدون",
    "Check out our blog" : "إلقي نظرة على مدوّنتنا",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
    "Migration started …" : "بدأت عملية الترحيل …",
    "An error occurred while changing your language. Please reload the page and try again." : "حدث خطأ أثناء تغيير إعدادات اللغة الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
    "An error occurred while changing your locale. Please reload the page and try again." : "حدث خطأ أثناء تغيير الإعدادات المحلية الخاصة بك. يرجى إعادة تحميل الصفحة والمحاوله مرة أخرى.",
    "Select a profile picture" : "اختر صورة الملف الشخصي ",
    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
    "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
    "Couldn't update app." : "تعذر تحديث التطبيق.",
    "All languages" : "كافة اللغات",
    "Everyone" : "الجميع",
    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
    "Please read carefully before activating server-side encryption: " : "يرجى الاطلاع بعناية قبل تفعيل التشفير في الخادم.",
    "Enable encryption" : "تنشيط التعمية",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد. يرجى تفعيل \"حزمة التشفير الإفتراضية\" وبعدها استخدم امر التشفير التالي 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "يجب عليك دمج مفتاح التشفير من التشفير السابق (ownCloud <= 8.0) إلى الجديد.",
    "Start migration" : "إبدأ الدمج",
    "days" : "أيام",
    "Upload new" : "رفع الان",
    "Select from Files" : "إختر مِن بين الملفات",
    "Remove image" : "إزالة الصورة",
    "Choose as profile picture" : "اختر صورة للملف الشخصي ",
    "You are using <strong>%s</strong>" : "تستخدم حاليا <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "تستخدم حاليا <strong>%1$s</strong> مِن أصل <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "No display name set" : "لم يتم إدخال أي إسم",
    "Address" : "العنوان",
    "Your postal address" : "عنوان البريد العادي",
    "Link https://…" : "الرابط https://…",
    "Twitter handle @…" : "حساب تويتر @…",
    "Avatar" : "الصورة الرمزية"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
